gchecky.model.address_filters_t

Package gchecky :: Module model :: Class address_filters_t |
[hide private]
[frames] | no frames]

# Class address_filters_t

source code

    object --+
             |
     gxml.Node --+
                 |
                address_filters_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| allowed_areas = `Node:PATH(allowed-areas):OPT:{ allowed_areas_t }`
| excluded_areas = `Node:PATH(excluded-areas):OPT:{ excluded_area`...``
| allow_us_po_box = `gxml.Boolean('allow-us-po-box', required= Fa`...``
| _fields = ``{``'``allow_us_po_box``'``:` `??``,` `'``allowed_areas``'``:` Node:PATH(all`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### excluded_areas Value:
      Node:PATH(excluded-areas):OPT:{ excluded_areas_t }

  ### allow_us_po_box Value:
      gxml.Boolean('allow-us-po-box', required= False)

  ### _fields list of meta-Fields of this class. Value:
      {'allow_us_po_box': ??,
       'allowed_areas': Node:PATH(allowed-areas):OPT:{ allowed_areas_t },
       'excluded_areas': Node:PATH(excluded-areas):OPT:{ excluded_areas_t }}